[libcxx-commits] [libcxx] Speed up std::invoke() compile times (~60%-85% reduction) (PR #213403)
via libcxx-commits
libcxx-commits at lists.llvm.org
Mon Aug 3 08:01:21 PDT 2026
higher-performance wrote:
@philnik777 one thought I had, though, was that this PR might be a reason to consider _removing_ `__builtin_invoke` and just doing everything with normal C++ code, since that's a maintenance burden for the compilers. After all, we see here the common case (ordinary function calls) are just as fast (or faster) with this approach, and the rarer cases are, well, rare.
https://github.com/llvm/llvm-project/pull/213403
More information about the libcxx-commits
mailing list